@@ -10,6 +10,8 @@ from typing import Any, Protocol, Sequence, TypeVar, get_origin, runtime_checkab
 
 from typing_extensions import Self
 
+from einspect.types import _SelfPtr
+
 log = logging.getLogger(__name__)
 
 Py_ssize_t = ctypes.c_ssize_t
@@ -27,6 +29,7 @@ class FuncPtr(Protocol):
 
 
 aliases = {
+    bool: ctypes.c_bool,
     # ctypes will cast c_ssize_t to (int)
     int: Py_ssize_t,
     # ctypes will cast py_object to (object)
@@ -101,6 +104,12 @@ def convert_type_hints(source: type, owner_cls: type) -> type | None:
     if isinstance(source, typing._GenericAlias):
         source = get_origin(source)
 
+    # For special SelfPtr object
+    if source is _SelfPtr:
+        res = POINTER(owner_cls)  # type: ignore
+        res.__module__ = owner_cls.__module__
+        return res
+
     if source in aliases:
         return aliases[source]
 
