@@ -66,6 +66,14 @@ def add_impls(type_: type, *attrs: str) -> None:
     attrs_set.update(attrs)
 
 
+def remove_impls(type_: type, *attrs: str) -> None:
+    """Remove a set of implemented attributes from the cache."""
+    attrs_set = wk_dict_getitem(_impls, type_)
+    if attrs_set is not None:
+        for attr in attrs:
+            attrs_set.discard(attr)
+
+
 def try_cache_attr(
     type_: type,
     name: str,
@@ -133,6 +141,16 @@ def get_type_cache(type_: type) -> dict[str, Any]:
         ) from None
 
 
+def get_impls(type_: type) -> set[str]:
+    """Get the impls cache for the type."""
+    try:
+        return wk_dict_getitem(_impls, type_)
+    except KeyError:
+        raise KeyError(
+            f"Original attributes cache was not found for type {type_!r}"
+        ) from None
+
+
 def normalize_slot_attr(attr: object | TypeNewWrapper) -> Any:
     """Normalize a slot attribute to its original value."""
     if isinstance(attr, TypeNewWrapper):
